Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(684)

Unified Diff: chrome/browser/chromeos/gdata/operations_base.h

Issue 10879061: Rename GDataOperationInterface to AuthenticatedOperationInterface (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/chromeos/gdata/operation_runner.cc ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/chromeos/gdata/operations_base.h
diff --git a/chrome/browser/chromeos/gdata/operations_base.h b/chrome/browser/chromeos/gdata/operations_base.h
index b7532c89046a2006a4e7ee1c0750fff5d7e206ea..edf0ad25550a83cfbd10dc2a24648babaf4928b2 100644
--- a/chrome/browser/chromeos/gdata/operations_base.h
+++ b/chrome/browser/chromeos/gdata/operations_base.h
@@ -53,16 +53,16 @@ class AuthOperation : public OperationRegistry::Operation,
DISALLOW_COPY_AND_ASSIGN(AuthOperation);
};
-//=========================== GDataOperationInterface ==========================
+//======================= AuthenticatedOperationInterface ======================
// An interface for implementing an operation used by DriveServiceInterface.
-class GDataOperationInterface {
+class AuthenticatedOperationInterface {
public:
// Callback to DriveServiceInterface upon for re-authentication.
- typedef base::Callback<void(GDataOperationInterface* operation)>
+ typedef base::Callback<void(AuthenticatedOperationInterface* operation)>
ReAuthenticateCallback;
- virtual ~GDataOperationInterface() {}
+ virtual ~AuthenticatedOperationInterface() {}
// Starts the actual operation after obtaining an authentication token
// |auth_token|.
@@ -85,14 +85,14 @@ typedef base::Callback<void(
scoped_ptr<std::string> content)> GetContentCallback;
// Base class for operations that are fetching URLs.
-class UrlFetchOperationBase : public GDataOperationInterface,
+class UrlFetchOperationBase : public AuthenticatedOperationInterface,
public OperationRegistry::Operation,
public net::URLFetcherDelegate {
public:
// Overridden from GDataOperationInterface.
virtual void Start(const std::string& auth_token) OVERRIDE;
// Overridden from GDataOperationInterface.
virtual void SetReAuthenticateCallback(
const ReAuthenticateCallback& callback) OVERRIDE;
@@ -137,7 +137,7 @@ class UrlFetchOperationBase : public GDataOperationInterface,
// Overridden from URLFetcherDelegate.
virtual void OnURLFetchComplete(const net::URLFetcher* source) OVERRIDE;
// Overridden from GDataOperationInterface.
virtual void OnAuthFailed(GDataErrorCode code) OVERRIDE;
// Invoked when ProcessURLFetchResults() is completed.
« no previous file with comments | « chrome/browser/chromeos/gdata/operation_runner.cc ('k') | no next file » | no next file with comments »
@@ -85,14 +85,14 @@ typedef base::Callback<void(
public net::URLFetcherDelegate {
public:
- // Overridden from GDataOperationInterface.
+ // Overridden from AuthenticatedOperationInterface.
virtual void Start(const std::string& auth_token) OVERRIDE;
@@ -85,14 +85,14 @@ typedef base::Callback<void(
virtual void Start(const std::string& auth_token) OVERRIDE;
- // Overridden from GDataOperationInterface.
+ // Overridden from AuthenticatedOperationInterface.
virtual void SetReAuthenticateCallback(
const ReAuthenticateCallback& callback) OVERRIDE;
@@ -137,7 +137,7 @@ class UrlFetchOperationBase : public GDataOperationInterface,
// Overridden from URLFetcherDelegate.
virtual void OnURLFetchComplete(const net::URLFetcher* source) OVERRIDE;
- // Overridden from GDataOperationInterface.
+ // Overridden from AuthenticatedOperationInterface.
virtual void OnAuthFailed(GDataErrorCode code) OVERRIDE;
// Invoked when ProcessURLFetchResults() is completed.

Powered by Google App Engine
This is Rietveld 408576698